"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ButType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ButTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ButType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BUT_INVALID: _ButType.ValueType  # 0
    """"""
    BUT_REDIRECT: _ButType.ValueType  # 1
    """"""
    BUT_LIKE: _ButType.ValueType  # 2
    """"""

class ButType(_ButType, metaclass=_ButTypeEnumTypeWrapper):
    """"""

BUT_INVALID: ButType.ValueType  # 0
""""""
BUT_REDIRECT: ButType.ValueType  # 1
""""""
BUT_LIKE: ButType.ValueType  # 2
""""""
global___ButType = ButType

class _TabType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TabTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TabType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TAB_INVALID: _TabType.ValueType  # 0
    """"""
    TAB_OGV_DETAIL: _TabType.ValueType  # 6
    """"""
    TAB_OGV_REPLY: _TabType.ValueType  # 7
    """"""
    TAB_FEED_BID: _TabType.ValueType  # 8
    """"""
    TAB_FEED_SMALL: _TabType.ValueType  # 9
    """"""

class TabType(_TabType, metaclass=_TabTypeEnumTypeWrapper):
    """"""

TAB_INVALID: TabType.ValueType  # 0
""""""
TAB_OGV_DETAIL: TabType.ValueType  # 6
""""""
TAB_OGV_REPLY: TabType.ValueType  # 7
""""""
TAB_FEED_BID: TabType.ValueType  # 8
""""""
TAB_FEED_SMALL: TabType.ValueType  # 9
""""""
global___TabType = TabType

@typing_extensions.final
class BigItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_IMAGE_URI_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON2_FIELD_NUMBER: builtins.int
    USER_CARD_FIELD_NUMBER: builtins.int
    LIKE_BUTTON_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover_image_uri: builtins.str
    """"""
    uri: builtins.str
    """"""
    cover_right_text: builtins.str
    """"""
    cover_left_text1: builtins.str
    """"""
    cover_left_icon1: builtins.int
    """"""
    cover_left_text2: builtins.str
    """"""
    cover_left_icon2: builtins.int
    """"""
    @property
    def user_card(self) -> global___UserCard:
        """"""
    @property
    def like_button(self) -> global___LikeButton:
        """"""
    param: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover_image_uri: builtins.str = ...,
        uri: builtins.str = ...,
        cover_right_text: builtins.str = ...,
        cover_left_text1: builtins.str = ...,
        cover_left_icon1: builtins.int = ...,
        cover_left_text2: builtins.str = ...,
        cover_left_icon2: builtins.int = ...,
        user_card: global___UserCard | None = ...,
        like_button: global___LikeButton | None = ...,
        param: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["like_button", b"like_button", "user_card", b"user_card"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover_image_uri", b"cover_image_uri", "cover_left_icon1", b"cover_left_icon1", "cover_left_icon2", b"cover_left_icon2", "cover_left_text1", b"cover_left_text1", "cover_left_text2", b"cover_left_text2", "cover_right_text", b"cover_right_text", "like_button", b"like_button", "param", b"param", "title", b"title", "uri", b"uri", "user_card", b"user_card"]) -> None: ...

global___BigItem = BigItem

@typing_extensions.final
class Button(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    BUT_TYPE_FIELD_NUMBER: builtins.int
    FOLLOW_STATE_FIELD_NUMBER: builtins.int
    HAS_TITLE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    link: builtins.str
    """"""
    id: builtins.str
    """"""
    icon: builtins.int
    """"""
    but_type: global___ButType.ValueType
    """"""
    follow_state: builtins.int
    """"""
    has_title: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        link: builtins.str = ...,
        id: builtins.str = ...,
        icon: builtins.int = ...,
        but_type: global___ButType.ValueType = ...,
        follow_state: builtins.int = ...,
        has_title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["but_type", b"but_type", "follow_state", b"follow_state", "has_title", b"has_title", "icon", b"icon", "id", b"id", "link", b"link", "title", b"title"]) -> None: ...

global___Button = Button

@typing_extensions.final
class Cast(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERSON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    @property
    def person(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MediaPerson]:
        """"""
    title: builtins.str
    """"""
    def __init__(
        self,
        *,
        person: collections.abc.Iterable[global___MediaPerson] | None = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["person", b"person", "title", b"title"]) -> None: ...

global___Cast = Cast

@typing_extensions.final
class ChannelInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    SUBSCRIBED_FIELD_NUMBER: builtins.int
    channel_id: builtins.int
    """"""
    subscribed: builtins.bool
    """"""
    def __init__(
        self,
        *,
        channel_id: builtins.int = ...,
        subscribed: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_id", b"channel_id", "subscribed", b"subscribed"]) -> None: ...

global___ChannelInfo = ChannelInfo

@typing_extensions.final
class LikeButton(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    SHOW_COUNT_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    SELECTED_FIELD_NUMBER: builtins.int
    EVENT_V2_FIELD_NUMBER: builtins.int
    LIKE_RESOURCE_FIELD_NUMBER: builtins.int
    DIS_LIKE_RESOURCE_FIELD_NUMBER: builtins.int
    LIKE_NIGHT_RESOURCE_FIELD_NUMBER: builtins.int
    DIS_LIKE_NIGHT_RESOURCE_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    count: builtins.int
    """"""
    show_count: builtins.bool
    """"""
    event: builtins.str
    """"""
    selected: builtins.int
    """"""
    event_v2: builtins.str
    """"""
    @property
    def like_resource(self) -> global___LikeButtonResource:
        """"""
    @property
    def dis_like_resource(self) -> global___LikeButtonResource:
        """"""
    @property
    def like_night_resource(self) -> global___LikeButtonResource:
        """"""
    @property
    def dis_like_night_resource(self) -> global___LikeButtonResource:
        """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        count: builtins.int = ...,
        show_count: builtins.bool = ...,
        event: builtins.str = ...,
        selected: builtins.int = ...,
        event_v2: builtins.str = ...,
        like_resource: global___LikeButtonResource | None = ...,
        dis_like_resource: global___LikeButtonResource | None = ...,
        like_night_resource: global___LikeButtonResource | None = ...,
        dis_like_night_resource: global___LikeButtonResource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dis_like_night_resource", b"dis_like_night_resource", "dis_like_resource", b"dis_like_resource", "like_night_resource", b"like_night_resource", "like_resource", b"like_resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "count", b"count", "dis_like_night_resource", b"dis_like_night_resource", "dis_like_resource", b"dis_like_resource", "event", b"event", "event_v2", b"event_v2", "like_night_resource", b"like_night_resource", "like_resource", b"like_resource", "selected", b"selected", "show_count", b"show_count"]) -> None: ...

global___LikeButton = LikeButton

@typing_extensions.final
class LikeButtonResource(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    url: builtins.str
    """"""
    hash: builtins.str
    """"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        hash: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hash", b"hash", "url", b"url"]) -> None: ...

global___LikeButtonResource = LikeButtonResource

@typing_extensions.final
class LikeCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIKE_FIELD_NUMBER: builtins.int
    IS_FOLLOW_FIELD_NUMBER: builtins.int
    like: builtins.int
    """"""
    is_follow: builtins.bool
    """"""
    def __init__(
        self,
        *,
        like: builtins.int = ...,
        is_follow: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_follow", b"is_follow", "like", b"like"]) -> None: ...

global___LikeCard = LikeCard

@typing_extensions.final
class MediaCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COVER_FIELD_NUMBER: builtins.int
    CUR_TITLE_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    BUT_FIRST_FIELD_NUMBER: builtins.int
    cover: builtins.str
    """"""
    cur_title: builtins.str
    """"""
    style: builtins.str
    """"""
    label: builtins.str
    """"""
    @property
    def but_first(self) -> global___Button:
        """"""
    def __init__(
        self,
        *,
        cover: builtins.str = ...,
        cur_title: builtins.str = ...,
        style: builtins.str = ...,
        label: builtins.str = ...,
        but_first: global___Button | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["but_first", b"but_first"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["but_first", b"but_first", "cover", b"cover", "cur_title", b"cur_title", "label", b"label", "style", b"style"]) -> None: ...

global___MediaCard = MediaCard

@typing_extensions.final
class MediaDetailReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAST_FIELD_NUMBER: builtins.int
    STAFF_FIELD_NUMBER: builtins.int
    OVERVIEW_FIELD_NUMBER: builtins.int
    @property
    def cast(self) -> global___Cast:
        """"""
    @property
    def staff(self) -> global___Staff:
        """"""
    @property
    def overview(self) -> global___Overview:
        """"""
    def __init__(
        self,
        *,
        cast: global___Cast | None = ...,
        staff: global___Staff | None = ...,
        overview: global___Overview | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cast", b"cast", "overview", b"overview", "staff", b"staff"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cast", b"cast", "overview", b"overview", "staff", b"staff"]) -> None: ...

global___MediaDetailReply = MediaDetailReply

@typing_extensions.final
class MediaDetailReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BIZ_ID_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    biz_id: builtins.int
    """"""
    biz_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        biz_id: builtins.int = ...,
        biz_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_id", b"biz_id", "biz_type", b"biz_type"]) -> None: ...

global___MediaDetailReq = MediaDetailReq

@typing_extensions.final
class MediaFollowReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MediaFollowReply = MediaFollowReply

@typing_extensions.final
class MediaFollowReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """"""
    type: builtins.int
    """"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "type", b"type"]) -> None: ...

global___MediaFollowReq = MediaFollowReq

@typing_extensions.final
class MediaPerson(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REAL_NAME_FIELD_NUMBER: builtins.int
    SQUARE_URL_FIELD_NUMBER: builtins.int
    CHARACTER_FIELD_NUMBER: builtins.int
    PERSON_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    real_name: builtins.str
    """"""
    square_url: builtins.str
    """"""
    character: builtins.str
    """"""
    person_id: builtins.int
    """"""
    type: builtins.str
    """"""
    def __init__(
        self,
        *,
        real_name: builtins.str = ...,
        square_url: builtins.str = ...,
        character: builtins.str = ...,
        person_id: builtins.int = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["character", b"character", "person_id", b"person_id", "real_name", b"real_name", "square_url", b"square_url", "type", b"type"]) -> None: ...

global___MediaPerson = MediaPerson

@typing_extensions.final
class MediaRelationReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OFFSET_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    offset: builtins.str
    """"""
    has_more: builtins.bool
    """"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SmallItem]:
        """"""
    def __init__(
        self,
        *,
        offset: builtins.str = ...,
        has_more: builtins.bool = ...,
        list: collections.abc.Iterable[global___SmallItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "list", b"list", "offset", b"offset"]) -> None: ...

global___MediaRelationReply = MediaRelationReply

@typing_extensions.final
class MediaRelationReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BIZ_ID_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    FEED_ID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PS_FIELD_NUMBER: builtins.int
    biz_id: builtins.int
    """"""
    biz_type: builtins.int
    """"""
    feed_id: builtins.int
    """"""
    offset: builtins.str
    """"""
    ps: builtins.int
    """"""
    def __init__(
        self,
        *,
        biz_id: builtins.int = ...,
        biz_type: builtins.int = ...,
        feed_id: builtins.int = ...,
        offset: builtins.str = ...,
        ps: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_id", b"biz_id", "biz_type", b"biz_type", "feed_id", b"feed_id", "offset", b"offset", "ps", b"ps"]) -> None: ...

global___MediaRelationReq = MediaRelationReq

@typing_extensions.final
class MediaTabReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEDIA_CARD_FIELD_NUMBER: builtins.int
    TAB_FIELD_NUMBER: builtins.int
    DEFAULT_TAB_INDEX_FIELD_NUMBER: builtins.int
    CHANNEL_INFO_FIELD_NUMBER: builtins.int
    @property
    def media_card(self) -> global___MediaCard:
        """"""
    @property
    def tab(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ShowTab]:
        """"""
    default_tab_index: builtins.int
    """"""
    @property
    def channel_info(self) -> global___ChannelInfo:
        """"""
    def __init__(
        self,
        *,
        media_card: global___MediaCard | None = ...,
        tab: collections.abc.Iterable[global___ShowTab] | None = ...,
        default_tab_index: builtins.int = ...,
        channel_info: global___ChannelInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["channel_info", b"channel_info", "media_card", b"media_card"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_info", b"channel_info", "default_tab_index", b"default_tab_index", "media_card", b"media_card", "tab", b"tab"]) -> None: ...

global___MediaTabReply = MediaTabReply

@typing_extensions.final
class MediaTabReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ArgsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BIZ_ID_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    biz_id: builtins.int
    """"""
    biz_type: builtins.int
    """"""
    source: builtins.str
    """"""
    spmid: builtins.str
    """"""
    @property
    def args(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    def __init__(
        self,
        *,
        biz_id: builtins.int = ...,
        biz_type: builtins.int = ...,
        source: builtins.str = ...,
        spmid: builtins.str = ...,
        args: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["args", b"args", "biz_id", b"biz_id", "biz_type", b"biz_type", "source", b"source", "spmid", b"spmid"]) -> None: ...

global___MediaTabReq = MediaTabReq

@typing_extensions.final
class MediaVideoReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OFFSET_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    offset: builtins.str
    """"""
    has_more: builtins.bool
    """"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BigItem]:
        """"""
    def __init__(
        self,
        *,
        offset: builtins.str = ...,
        has_more: builtins.bool = ...,
        list: collections.abc.Iterable[global___BigItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "list", b"list", "offset", b"offset"]) -> None: ...

global___MediaVideoReply = MediaVideoReply

@typing_extensions.final
class MediaVideoReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BIZ_ID_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    FEED_ID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PS_FIELD_NUMBER: builtins.int
    biz_id: builtins.int
    """"""
    biz_type: builtins.int
    """"""
    feed_id: builtins.int
    """"""
    offset: builtins.str
    """"""
    ps: builtins.int
    """"""
    def __init__(
        self,
        *,
        biz_id: builtins.int = ...,
        biz_type: builtins.int = ...,
        feed_id: builtins.int = ...,
        offset: builtins.str = ...,
        ps: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_id", b"biz_id", "biz_type", b"biz_type", "feed_id", b"feed_id", "offset", b"offset", "ps", b"ps"]) -> None: ...

global___MediaVideoReq = MediaVideoReq

@typing_extensions.final
class Overview(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    text: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text", "title", b"title"]) -> None: ...

global___Overview = Overview

@typing_extensions.final
class ShowTab(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAB_TYPE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    tab_type: global___TabType.ValueType
    """"""
    title: builtins.str
    """"""
    url: builtins.str
    """"""
    def __init__(
        self,
        *,
        tab_type: global___TabType.ValueType = ...,
        title: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tab_type", b"tab_type", "title", b"title", "url", b"url"]) -> None: ...

global___ShowTab = ShowTab

@typing_extensions.final
class SmallItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_IMAGE_URI_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON2_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover_image_uri: builtins.str
    """"""
    uri: builtins.str
    """"""
    cover_right_text: builtins.str
    """"""
    cover_left_text1: builtins.str
    """"""
    cover_left_icon1: builtins.int
    """"""
    cover_left_text2: builtins.str
    """"""
    cover_left_icon2: builtins.int
    """"""
    param: builtins.int
    """"""
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover_image_uri: builtins.str = ...,
        uri: builtins.str = ...,
        cover_right_text: builtins.str = ...,
        cover_left_text1: builtins.str = ...,
        cover_left_icon1: builtins.int = ...,
        cover_left_text2: builtins.str = ...,
        cover_left_icon2: builtins.int = ...,
        param: builtins.int = ...,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover_image_uri", b"cover_image_uri", "cover_left_icon1", b"cover_left_icon1", "cover_left_icon2", b"cover_left_icon2", "cover_left_text1", b"cover_left_text1", "cover_left_text2", b"cover_left_text2", "cover_right_text", b"cover_right_text", "mid", b"mid", "param", b"param", "title", b"title", "uri", b"uri"]) -> None: ...

global___SmallItem = SmallItem

@typing_extensions.final
class Staff(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    text: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text", "title", b"title"]) -> None: ...

global___Staff = Staff

@typing_extensions.final
class UserCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_NAME_FIELD_NUMBER: builtins.int
    USER_FACE_FIELD_NUMBER: builtins.int
    USER_URL_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    user_name: builtins.str
    """"""
    user_face: builtins.str
    """"""
    user_url: builtins.str
    """"""
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        user_name: builtins.str = ...,
        user_face: builtins.str = ...,
        user_url: builtins.str = ...,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid", "user_face", b"user_face", "user_name", b"user_name", "user_url", b"user_url"]) -> None: ...

global___UserCard = UserCard



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.api.probe.v1 import probe_pb2 as bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2


class ProbeStub(object):
    """服务可用性探针
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.TestCode = channel.unary_unary(
                '/bilibili.api.probe.v1.Probe/TestCode',
                request_serializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.CodeReq.SerializeToString,
                response_deserializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.CodeReply.FromString,
                )
        self.TestReq = channel.unary_unary(
                '/bilibili.api.probe.v1.Probe/TestReq',
                request_serializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ProbeReq.SerializeToString,
                response_deserializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ProbeReply.FromString,
                )
        self.TestStream = channel.unary_unary(
                '/bilibili.api.probe.v1.Probe/TestStream',
                request_serializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ProbeStreamReq.SerializeToString,
                response_deserializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ProbeStreamReply.FromString,
                )
        self.TestSub = channel.unary_unary(
                '/bilibili.api.probe.v1.Probe/TestSub',
                request_serializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ProbeSubReq.SerializeToString,
                response_deserializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ProbeSubReply.FromString,
                )


class ProbeServicer(object):
    """服务可用性探针
    """

    def TestCode(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestReq(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestStream(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestSub(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProbeServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'TestCode': grpc.unary_unary_rpc_method_handler(
                    servicer.TestCode,
                    request_deserializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.CodeReq.FromString,
                    response_serializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.CodeReply.SerializeToString,
            ),
            'TestReq': grpc.unary_unary_rpc_method_handler(
                    servicer.TestReq,
                    request_deserializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ProbeReq.FromString,
                    response_serializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ProbeReply.SerializeToString,
            ),
            'TestStream': grpc.unary_unary_rpc_method_handler(
                    servicer.TestStream,
                    request_deserializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ProbeStreamReq.FromString,
                    response_serializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ProbeStreamReply.SerializeToString,
            ),
            'TestSub': grpc.unary_unary_rpc_method_handler(
                    servicer.TestSub,
                    request_deserializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ProbeSubReq.FromString,
                    response_serializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ProbeSubReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.api.probe.v1.Probe', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Probe(object):
    """服务可用性探针
    """

    @staticmethod
    def TestCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.api.probe.v1.Probe/TestCode',
            bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.CodeReq.SerializeToString,
            bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.CodeReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TestReq(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.api.probe.v1.Probe/TestReq',
            bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ProbeReq.SerializeToString,
            bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ProbeReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TestStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.api.probe.v1.Probe/TestStream',
            bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ProbeStreamReq.SerializeToString,
            bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ProbeStreamReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TestSub(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.api.probe.v1.Probe/TestSub',
            bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ProbeSubReq.SerializeToString,
            bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ProbeSubReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class ProbeServiceStub(object):
    """服务可用性探针
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Echo = channel.unary_unary(
                '/bilibili.api.probe.v1.ProbeService/Echo',
                request_serializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.SimpleMessage.SerializeToString,
                response_deserializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.SimpleMessage.FromString,
                )
        self.EchoBody = channel.unary_unary(
                '/bilibili.api.probe.v1.ProbeService/EchoBody',
                request_serializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.SimpleMessage.SerializeToString,
                response_deserializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.SimpleMessage.FromString,
                )
        self.EchoDelete = channel.unary_unary(
                '/bilibili.api.probe.v1.ProbeService/EchoDelete',
                request_serializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.SimpleMessage.SerializeToString,
                response_deserializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.SimpleMessage.FromString,
                )
        self.EchoError = channel.unary_unary(
                '/bilibili.api.probe.v1.ProbeService/EchoError',
                request_serializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ErrorMessage.SerializeToString,
                response_deserializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ErrorMessage.FromString,
                )
        self.EchoPatch = channel.unary_unary(
                '/bilibili.api.probe.v1.ProbeService/EchoPatch',
                request_serializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.DynamicMessageUpdate.SerializeToString,
                response_deserializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.DynamicMessageUpdate.FromString,
                )


class ProbeServiceServicer(object):
    """服务可用性探针
    """

    def Echo(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EchoBody(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EchoDelete(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EchoError(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EchoPatch(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProbeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Echo': grpc.unary_unary_rpc_method_handler(
                    servicer.Echo,
                    request_deserializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.SimpleMessage.FromString,
                    response_serializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.SimpleMessage.SerializeToString,
            ),
            'EchoBody': grpc.unary_unary_rpc_method_handler(
                    servicer.EchoBody,
                    request_deserializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.SimpleMessage.FromString,
                    response_serializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.SimpleMessage.SerializeToString,
            ),
            'EchoDelete': grpc.unary_unary_rpc_method_handler(
                    servicer.EchoDelete,
                    request_deserializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.SimpleMessage.FromString,
                    response_serializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.SimpleMessage.SerializeToString,
            ),
            'EchoError': grpc.unary_unary_rpc_method_handler(
                    servicer.EchoError,
                    request_deserializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ErrorMessage.FromString,
                    response_serializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ErrorMessage.SerializeToString,
            ),
            'EchoPatch': grpc.unary_unary_rpc_method_handler(
                    servicer.EchoPatch,
                    request_deserializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.DynamicMessageUpdate.FromString,
                    response_serializer=bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.DynamicMessageUpdate.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.api.probe.v1.ProbeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProbeService(object):
    """服务可用性探针
    """

    @staticmethod
    def Echo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.api.probe.v1.ProbeService/Echo',
            bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.SimpleMessage.SerializeToString,
            bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.SimpleMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EchoBody(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.api.probe.v1.ProbeService/EchoBody',
            bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.SimpleMessage.SerializeToString,
            bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.SimpleMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EchoDelete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.api.probe.v1.ProbeService/EchoDelete',
            bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.SimpleMessage.SerializeToString,
            bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.SimpleMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EchoError(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.api.probe.v1.ProbeService/EchoError',
            bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ErrorMessage.SerializeToString,
            bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.ErrorMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EchoPatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.api.probe.v1.ProbeService/EchoPatch',
            bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.DynamicMessageUpdate.SerializeToString,
            bilibili_dot_api_dot_probe_dot_v1_dot_probe__pb2.DynamicMessageUpdate.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/playershared/playershared.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(bilibili/playershared/playershared.proto\x12\x15\x62ilibili.playershared\"\x84\x01\n\x07\x41rcConf\x12\x12\n\nis_support\x18\x01 \x01(\x08\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\x12:\n\rextra_content\x18\x03 \x01(\x0b\x32#.bilibili.playershared.ExtraContent\x12\x17\n\x0funsupport_scene\x18\x04 \x03(\x05\"\xa1\x01\n\x06\x42utton\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\x12\x46\n\rreport_params\x18\x03 \x03(\x0b\x32/.bilibili.playershared.Button.ReportParamsEntry\x1a\x33\n\x11ReportParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"B\n\tConfValue\x12\x14\n\nswitch_val\x18\x01 \x01(\x05H\x00\x12\x16\n\x0cselected_val\x18\x02 \x01(\x05H\x00\x42\x07\n\x05value\"\xa6\x01\n\x08\x44\x61shItem\x12\n\n\x02id\x18\x01 \x01(\r\x12\x10\n\x08\x62\x61se_url\x18\x02 \x01(\t\x12\x12\n\nbackup_url\x18\x03 \x03(\t\x12\x11\n\tbandwidth\x18\x04 \x01(\r\x12\x0f\n\x07\x63odecid\x18\x05 \x01(\r\x12\x0b\n\x03md5\x18\x06 \x01(\t\x12\x0c\n\x04size\x18\x07 \x01(\x04\x12\x12\n\nframe_rate\x18\x08 \x01(\t\x12\x15\n\rwidevine_pssh\x18\t \x01(\t\"\xe0\x01\n\tDashVideo\x12\x10\n\x08\x62\x61se_url\x18\x01 \x01(\t\x12\x12\n\nbackup_url\x18\x02 \x03(\t\x12\x11\n\tbandwidth\x18\x03 \x01(\r\x12\x0f\n\x07\x63odecid\x18\x04 \x01(\r\x12\x0b\n\x03md5\x18\x05 \x01(\t\x12\x0c\n\x04size\x18\x06 \x01(\x04\x12\x10\n\x08\x61udio_id\x18\x07 \x01(\r\x12\x12\n\nno_rexcode\x18\x08 \x01(\x08\x12\x12\n\nframe_rate\x18\t \x01(\t\x12\r\n\x05width\x18\n \x01(\x05\x12\x0e\n\x06height\x18\x0b \x01(\x05\x12\x15\n\rwidevine_pssh\x18\x0c \x01(\t\"B\n\nDeviceConf\x12\x34\n\nconf_value\x18\x01 \x01(\x0b\x32 .bilibili.playershared.ConfValue\":\n\tDimension\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12\x0e\n\x06rotate\x18\x03 \x01(\x05\"\x99\x01\n\tDolbyItem\x12\x33\n\x04type\x18\x01 \x01(\x0e\x32%.bilibili.playershared.DolbyItem.Type\x12.\n\x05\x61udio\x18\x02 \x03(\x0b\x32\x1f.bilibili.playershared.DashItem\"\'\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x43OMMON\x10\x01\x12\t\n\x05\x41TMOS\x10\x02\"4\n\x05\x45vent\x12+\n\x05shake\x18\x01 \x01(\x0b\x32\x1c.bilibili.playershared.Shake\"<\n\x0c\x45xtraContent\x12\x16\n\x0e\x64isable_reason\x18\x01 \x01(\t\x12\x14\n\x0c\x64isable_code\x18\x02 \x01(\x03\"\x7f\n\x07History\x12\x39\n\rcurrent_video\x18\x01 \x01(\x0b\x32\".bilibili.playershared.HistoryInfo\x12\x39\n\rrelated_video\x18\x02 \x01(\x0b\x32\".bilibili.playershared.HistoryInfo\"\xb4\x01\n\x0bHistoryInfo\x12\x10\n\x08progress\x18\x01 \x01(\x03\x12\x15\n\rlast_play_cid\x18\x02 \x01(\x03\x12+\n\x05toast\x18\x03 \x01(\x0b\x32\x1c.bilibili.playershared.Toast\x12\x38\n\x12toast_without_time\x18\x04 \x01(\x0b\x32\x1c.bilibili.playershared.Toast\x12\x15\n\rlast_play_aid\x18\x05 \x01(\x03\"r\n\x0bInteraction\x12\x31\n\x0chistory_node\x18\x01 \x01(\x0b\x32\x1b.bilibili.playershared.Node\x12\x15\n\rgraph_version\x18\x02 \x01(\x03\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\x0c\n\x04mark\x18\x04 \x01(\x03\"k\n\x0cLossLessItem\x12\x19\n\x11is_lossless_audio\x18\x01 \x01(\x08\x12.\n\x05\x61udio\x18\x02 \x01(\x0b\x32\x1f.bilibili.playershared.DashItem\x12\x10\n\x08need_vip\x18\x03 \x01(\x08\"3\n\x04Node\x12\x0f\n\x07node_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\"\xb4\x02\n\x07PlayArc\x12\x34\n\nvideo_type\x18\x01 \x01(\x0e\x32 .bilibili.playershared.VideoType\x12\x0b\n\x03\x61id\x18\x02 \x01(\x04\x12\x0b\n\x03\x63id\x18\x03 \x01(\x04\x12\x39\n\rdrm_tech_type\x18\x04 \x01(\x0e\x32\".bilibili.playershared.DrmTechType\x12\x30\n\x08\x61rc_type\x18\x05 \x01(\x0e\x32\x1e.bilibili.playershared.ArcType\x12\x37\n\x0binteraction\x18\x06 \x01(\x0b\x32\".bilibili.playershared.Interaction\x12\x33\n\tdimension\x18\x07 \x01(\x0b\x32 .bilibili.playershared.Dimension\"\xa3\x01\n\x0bPlayArcConf\x12\x43\n\tarc_confs\x18\x01 \x03(\x0b\x32\x30.bilibili.playershared.PlayArcConf.ArcConfsEntry\x1aO\n\rArcConfsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.bilibili.playershared.ArcConf:\x02\x38\x01\"\xb5\x01\n\x0ePlayDeviceConf\x12L\n\x0c\x64\x65vice_confs\x18\x01 \x03(\x0b\x32\x36.bilibili.playershared.PlayDeviceConf.DeviceConfsEntry\x1aU\n\x10\x44\x65viceConfsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32!.bilibili.playershared.DeviceConf:\x02\x38\x01\"\xff\x01\n\x0bQnTrialInfo\x12\x12\n\ntrial_able\x18\x01 \x01(\x08\x12\x17\n\x0fremaining_times\x18\x02 \x01(\x05\x12\r\n\x05start\x18\x03 \x01(\x05\x12\x13\n\x0btime_length\x18\x04 \x01(\x05\x12\x31\n\x0bstart_toast\x18\x05 \x01(\x0b\x32\x1c.bilibili.playershared.Toast\x12/\n\tend_toast\x18\x06 \x01(\x0b\x32\x1c.bilibili.playershared.Toast\x12;\n\x14quality_open_tip_btn\x18\x08 \x01(\x0b\x32\x1d.bilibili.playershared.Button\"n\n\x0cResponseDash\x12.\n\x05video\x18\x01 \x03(\x0b\x32\x1f.bilibili.playershared.DashItem\x12.\n\x05\x61udio\x18\x02 \x03(\x0b\x32\x1f.bilibili.playershared.DashItem\"h\n\x0bResponseUrl\x12\r\n\x05order\x18\x01 \x01(\r\x12\x0e\n\x06length\x18\x02 \x01(\x04\x12\x0c\n\x04size\x18\x03 \x01(\x04\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x12\n\nbackup_url\x18\x05 \x03(\t\x12\x0b\n\x03md5\x18\x06 \x01(\t\"\x81\x01\n\x06Scheme\x12=\n\x0b\x61\x63tion_type\x18\x01 \x01(\x0e\x32(.bilibili.playershared.Scheme.ActionType\x12\r\n\x05toast\x18\x02 \x01(\t\")\n\nActionType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nSHOW_TOAST\x10\x01\"C\n\x0cSegmentVideo\x12\x33\n\x07segment\x18\x01 \x03(\x0b\x32\".bilibili.playershared.ResponseUrl\"\x15\n\x05Shake\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\"\xc1\x01\n\x06Stream\x12\x36\n\x0bstream_info\x18\x01 \x01(\x0b\x32!.bilibili.playershared.StreamInfo\x12\x36\n\ndash_video\x18\x02 \x01(\x0b\x32 .bilibili.playershared.DashVideoH\x00\x12<\n\rsegment_video\x18\x03 \x01(\x0b\x32#.bilibili.playershared.SegmentVideoH\x00\x42\t\n\x07\x63ontent\"\x90\x03\n\nStreamInfo\x12\x0f\n\x07quality\x18\x01 \x01(\r\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x65rr_code\x18\x04 \x01(\r\x12\x31\n\x05limit\x18\x05 \x01(\x0b\x32\".bilibili.playershared.StreamLimit\x12\x10\n\x08need_vip\x18\x06 \x01(\x08\x12\x12\n\nneed_login\x18\x07 \x01(\x08\x12\x0e\n\x06intact\x18\x08 \x01(\x08\x12\x12\n\nno_rexcode\x18\t \x01(\x08\x12\x11\n\tattribute\x18\n \x01(\x03\x12\x17\n\x0fnew_description\x18\x0b \x01(\t\x12\x14\n\x0c\x64isplay_desc\x18\x0c \x01(\t\x12\x13\n\x0bsuperscript\x18\r \x01(\t\x12\x10\n\x08vip_free\x18\x0e \x01(\x08\x12\x10\n\x08subtitle\x18\x0f \x01(\t\x12-\n\x06scheme\x18\x10 \x01(\x0b\x32\x1d.bilibili.playershared.Scheme\x12\x13\n\x0bsupport_drm\x18\x11 \x01(\x08\"6\n\x0bStreamLimit\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\"D\n\x05Toast\x12\x0c\n\x04text\x18\x01 \x01(\t\x12-\n\x06\x62utton\x18\x02 \x01(\x0b\x32\x1d.bilibili.playershared.Button\"\xd6\x01\n\x08VideoVod\x12\x0b\n\x03\x61id\x18\x01 \x01(\x05\x12\x0b\n\x03\x63id\x18\x02 \x01(\x05\x12\n\n\x02qn\x18\x03 \x01(\x04\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x06 \x01(\r\x12\x12\n\nforce_host\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x08\x12:\n\x11prefer_codec_type\x18\t \x01(\x0e\x32\x1f.bilibili.playershared.CodeType\x12\x15\n\rvoice_balance\x18\n \x01(\x04\"\xf8\x02\n\x07VodInfo\x12\x0f\n\x07quality\x18\x01 \x01(\r\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x12\n\ntimelength\x18\x03 \x01(\x04\x12\x15\n\rvideo_codecid\x18\x04 \x01(\r\x12\x32\n\x0bstream_list\x18\x05 \x03(\x0b\x32\x1d.bilibili.playershared.Stream\x12\x33\n\ndash_audio\x18\x06 \x03(\x0b\x32\x1f.bilibili.playershared.DashItem\x12/\n\x05\x64olby\x18\x07 \x01(\x0b\x32 .bilibili.playershared.DolbyItem\x12\x31\n\x06volume\x18\x08 \x01(\x0b\x32!.bilibili.playershared.VolumeInfo\x12;\n\x0eloss_less_item\x18\t \x01(\x0b\x32#.bilibili.playershared.LossLessItem\x12\x17\n\x0fsupport_project\x18\n \x01(\x08\"\xa3\x01\n\nVolumeInfo\x12\x12\n\nmeasured_i\x18\x01 \x01(\x01\x12\x14\n\x0cmeasured_lra\x18\x02 \x01(\x01\x12\x13\n\x0bmeasured_tp\x18\x03 \x01(\x01\x12\x1a\n\x12measured_threshold\x18\x04 \x01(\x01\x12\x15\n\rtarget_offset\x18\x05 \x01(\x01\x12\x10\n\x08target_i\x18\x06 \x01(\x01\x12\x11\n\ttarget_tp\x18\x07 \x01(\x01*5\n\x07\x41rcType\x12\x13\n\x0f\x41RC_TYPE_NORMAL\x10\x00\x12\x15\n\x11\x41RC_TYPE_INTERACT\x10\x01*=\n\x08\x43odeType\x12\n\n\x06NOCODE\x10\x00\x12\x0b\n\x07\x43ODE264\x10\x01\x12\x0b\n\x07\x43ODE265\x10\x02\x12\x0b\n\x07\x43ODEAV1\x10\x03*\x9a\x04\n\x08\x43onfType\x12\n\n\x06NoType\x10\x00\x12\x0c\n\x08\x46LIPCONF\x10\x01\x12\x0c\n\x08\x43\x41STCONF\x10\x02\x12\x0c\n\x08\x46\x45\x45\x44\x42\x41\x43K\x10\x03\x12\x0c\n\x08SUBTITLE\x10\x04\x12\x10\n\x0cPLAYBACKRATE\x10\x05\x12\n\n\x06TIMEUP\x10\x06\x12\x10\n\x0cPLAYBACKMODE\x10\x07\x12\r\n\tSCALEMODE\x10\x08\x12\x12\n\x0e\x42\x41\x43KGROUNDPLAY\x10\t\x12\x08\n\x04LIKE\x10\n\x12\x0b\n\x07\x44ISLIKE\x10\x0b\x12\x08\n\x04\x43OIN\x10\x0c\x12\x08\n\x04\x45LEC\x10\r\x12\t\n\x05SHARE\x10\x0e\x12\x0e\n\nSCREENSHOT\x10\x0f\x12\x0e\n\nLOCKSCREEN\x10\x10\x12\r\n\tRECOMMEND\x10\x11\x12\x11\n\rPLAYBACKSPEED\x10\x12\x12\x0e\n\nDEFINITION\x10\x13\x12\x0e\n\nSELECTIONS\x10\x14\x12\x08\n\x04NEXT\x10\x15\x12\n\n\x06\x45\x44ITDM\x10\x16\x12\x0f\n\x0bSMALLWINDOW\x10\x17\x12\t\n\x05SHAKE\x10\x18\x12\x0b\n\x07OUTERDM\x10\x19\x12\x0b\n\x07INNERDM\x10\x1a\x12\x0c\n\x08PANORAMA\x10\x1b\x12\t\n\x05\x44OLBY\x10\x1c\x12\x0f\n\x0b\x43OLORFILTER\x10\x1d\x12\x0c\n\x08LOSSLESS\x10\x1e\x12\x0e\n\nFREYAENTER\x10\x1f\x12\x12\n\x0e\x46REYAFULLENTER\x10 \x12\x0c\n\x08SKIPOPED\x10!\x12\x10\n\x0cRECORDSCREEN\x10\"\x12\x0b\n\x07\x44UBBING\x10#\x12\n\n\x06LISTEN\x10$*J\n\x0b\x44rmTechType\x12\x0f\n\x0bUNKNOWN_DRM\x10\x00\x12\r\n\tFAIR_PLAY\x10\x01\x12\r\n\tWIDE_VINE\x10\x02\x12\x0c\n\x08\x42ILI_DRM\x10\x03*1\n\x07PlayErr\x12\t\n\x05NoErr\x10\x00\x12\x1b\n\x17WithMultiDeviceLoginErr\x10\x01*1\n\x0eUnsupportScene\x12\x11\n\rUNKNOWN_SCENE\x10\x00\x12\x0c\n\x08PREMIERE\x10\x01**\n\tVideoType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03UGC\x10\x01\x12\x07\n\x03PGC\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.playershared.playershared_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BUTTON_REPORTPARAMSENTRY._options = None
  _BUTTON_REPORTPARAMSENTRY._serialized_options = b'8\001'
  _PLAYARCCONF_ARCCONFSENTRY._options = None
  _PLAYARCCONF_ARCCONFSENTRY._serialized_options = b'8\001'
  _PLAYDEVICECONF_DEVICECONFSENTRY._options = None
  _PLAYDEVICECONF_DEVICECONFSENTRY._serialized_options = b'8\001'
  _globals['_ARCTYPE']._serialized_start=4668
  _globals['_ARCTYPE']._serialized_end=4721
  _globals['_CODETYPE']._serialized_start=4723
  _globals['_CODETYPE']._serialized_end=4784
  _globals['_CONFTYPE']._serialized_start=4787
  _globals['_CONFTYPE']._serialized_end=5325
  _globals['_DRMTECHTYPE']._serialized_start=5327
  _globals['_DRMTECHTYPE']._serialized_end=5401
  _globals['_PLAYERR']._serialized_start=5403
  _globals['_PLAYERR']._serialized_end=5452
  _globals['_UNSUPPORTSCENE']._serialized_start=5454
  _globals['_UNSUPPORTSCENE']._serialized_end=5503
  _globals['_VIDEOTYPE']._serialized_start=5505
  _globals['_VIDEOTYPE']._serialized_end=5547
  _globals['_ARCCONF']._serialized_start=68
  _globals['_ARCCONF']._serialized_end=200
  _globals['_BUTTON']._serialized_start=203
  _globals['_BUTTON']._serialized_end=364
  _globals['_BUTTON_REPORTPARAMSENTRY']._serialized_start=313
  _globals['_BUTTON_REPORTPARAMSENTRY']._serialized_end=364
  _globals['_CONFVALUE']._serialized_start=366
  _globals['_CONFVALUE']._serialized_end=432
  _globals['_DASHITEM']._serialized_start=435
  _globals['_DASHITEM']._serialized_end=601
  _globals['_DASHVIDEO']._serialized_start=604
  _globals['_DASHVIDEO']._serialized_end=828
  _globals['_DEVICECONF']._serialized_start=830
  _globals['_DEVICECONF']._serialized_end=896
  _globals['_DIMENSION']._serialized_start=898
  _globals['_DIMENSION']._serialized_end=956
  _globals['_DOLBYITEM']._serialized_start=959
  _globals['_DOLBYITEM']._serialized_end=1112
  _globals['_DOLBYITEM_TYPE']._serialized_start=1073
  _globals['_DOLBYITEM_TYPE']._serialized_end=1112
  _globals['_EVENT']._serialized_start=1114
  _globals['_EVENT']._serialized_end=1166
  _globals['_EXTRACONTENT']._serialized_start=1168
  _globals['_EXTRACONTENT']._serialized_end=1228
  _globals['_HISTORY']._serialized_start=1230
  _globals['_HISTORY']._serialized_end=1357
  _globals['_HISTORYINFO']._serialized_start=1360
  _globals['_HISTORYINFO']._serialized_end=1540
  _globals['_INTERACTION']._serialized_start=1542
  _globals['_INTERACTION']._serialized_end=1656
  _globals['_LOSSLESSITEM']._serialized_start=1658
  _globals['_LOSSLESSITEM']._serialized_end=1765
  _globals['_NODE']._serialized_start=1767
  _globals['_NODE']._serialized_end=1818
  _globals['_PLAYARC']._serialized_start=1821
  _globals['_PLAYARC']._serialized_end=2129
  _globals['_PLAYARCCONF']._serialized_start=2132
  _globals['_PLAYARCCONF']._serialized_end=2295
  _globals['_PLAYARCCONF_ARCCONFSENTRY']._serialized_start=2216
  _globals['_PLAYARCCONF_ARCCONFSENTRY']._serialized_end=2295
  _globals['_PLAYDEVICECONF']._serialized_start=2298
  _globals['_PLAYDEVICECONF']._serialized_end=2479
  _globals['_PLAYDEVICECONF_DEVICECONFSENTRY']._serialized_start=2394
  _globals['_PLAYDEVICECONF_DEVICECONFSENTRY']._serialized_end=2479
  _globals['_QNTRIALINFO']._serialized_start=2482
  _globals['_QNTRIALINFO']._serialized_end=2737
  _globals['_RESPONSEDASH']._serialized_start=2739
  _globals['_RESPONSEDASH']._serialized_end=2849
  _globals['_RESPONSEURL']._serialized_start=2851
  _globals['_RESPONSEURL']._serialized_end=2955
  _globals['_SCHEME']._serialized_start=2958
  _globals['_SCHEME']._serialized_end=3087
  _globals['_SCHEME_ACTIONTYPE']._serialized_start=3046
  _globals['_SCHEME_ACTIONTYPE']._serialized_end=3087
  _globals['_SEGMENTVIDEO']._serialized_start=3089
  _globals['_SEGMENTVIDEO']._serialized_end=3156
  _globals['_SHAKE']._serialized_start=3158
  _globals['_SHAKE']._serialized_end=3179
  _globals['_STREAM']._serialized_start=3182
  _globals['_STREAM']._serialized_end=3375
  _globals['_STREAMINFO']._serialized_start=3378
  _globals['_STREAMINFO']._serialized_end=3778
  _globals['_STREAMLIMIT']._serialized_start=3780
  _globals['_STREAMLIMIT']._serialized_end=3834
  _globals['_TOAST']._serialized_start=3836
  _globals['_TOAST']._serialized_end=3904
  _globals['_VIDEOVOD']._serialized_start=3907
  _globals['_VIDEOVOD']._serialized_end=4121
  _globals['_VODINFO']._serialized_start=4124
  _globals['_VODINFO']._serialized_end=4500
  _globals['_VOLUMEINFO']._serialized_start=4503
  _globals['_VOLUMEINFO']._serialized_end=4666
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PlayLimitCode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PlayLimitCodeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PlayLimitCode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PLC_UNKNOWN: _PlayLimitCode.ValueType  # 0
    PLC_NOTPAYED: _PlayLimitCode.ValueType  # 1

class PlayLimitCode(_PlayLimitCode, metaclass=_PlayLimitCodeEnumTypeWrapper): ...

PLC_UNKNOWN: PlayLimitCode.ValueType  # 0
PLC_NOTPAYED: PlayLimitCode.ValueType  # 1
global___PlayLimitCode = PlayLimitCode

@typing_extensions.final
class ButtonStyle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    JUMP_LINK_FIELD_NUMBER: builtins.int
    text: builtins.str
    text_color: builtins.str
    bg_color: builtins.str
    jump_link: builtins.str
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        text_color: builtins.str = ...,
        bg_color: builtins.str = ...,
        jump_link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "jump_link", b"jump_link", "text", b"text", "text_color", b"text_color"]) -> None: ...

global___ButtonStyle = ButtonStyle

@typing_extensions.final
class PlayLimit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    SUB_MESSAGE_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    code: global___PlayLimitCode.ValueType
    message: builtins.str
    sub_message: builtins.str
    @property
    def button(self) -> global___ButtonStyle: ...
    def __init__(
        self,
        *,
        code: global___PlayLimitCode.ValueType = ...,
        message: builtins.str = ...,
        sub_message: builtins.str = ...,
        button: global___ButtonStyle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "code", b"code", "message", b"message", "sub_message", b"sub_message"]) -> None: ...

global___PlayLimit = PlayLimit

@typing_extensions.final
class UGCAnyModel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAY_LIMIT_FIELD_NUMBER: builtins.int
    @property
    def play_limit(self) -> global___PlayLimit: ...
    def __init__(
        self,
        *,
        play_limit: global___PlayLimit | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["play_limit", b"play_limit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["play_limit", b"play_limit"]) -> None: ...

global___UGCAnyModel = UGCAnyModel



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/pgc/gateway/player/v1/playurl.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.playurl.v1 import playurl_pb2 as bilibili_dot_app_dot_playurl_dot_v1_dot_playurl__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,bilibili/pgc/gateway/player/v1/playurl.proto\x12\x1e\x62ilibili.pgc.gateway.player.v1\x1a%bilibili/app/playurl/v1/playurl.proto\"D\n\x0c\x42usinessInfo\x12\x12\n\nis_preview\x18\x01 \x01(\x08\x12\n\n\x02\x62p\x18\x02 \x01(\x08\x12\x14\n\x0cmarlin_token\x18\x03 \x01(\t\"=\n\x05\x45vent\x12\x34\n\x05shake\x18\x01 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v1.Shake\"\xb2\x01\n\x0cLivePlayInfo\x12\x12\n\ncurrent_qn\x18\x01 \x01(\x05\x12O\n\x13quality_description\x18\x02 \x03(\x0b\x32\x32.bilibili.pgc.gateway.player.v1.QualityDescription\x12=\n\x04\x64url\x18\x03 \x03(\x0b\x32/.bilibili.pgc.gateway.player.v1.ResponseDataUrl\"\x91\x01\n\x11LivePlayViewReply\x12;\n\troom_info\x18\x01 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v1.RoomInfo\x12?\n\tplay_info\x18\x02 \x01(\x0b\x32,.bilibili.pgc.gateway.player.v1.LivePlayInfo\"w\n\x0fLivePlayViewReq\x12\r\n\x05\x65p_id\x18\x01 \x01(\x03\x12\x0f\n\x07quality\x18\x02 \x01(\r\x12\r\n\x05ptype\x18\x03 \x01(\r\x12\r\n\x05https\x18\x04 \x01(\x08\x12\x11\n\tplay_type\x18\x05 \x01(\r\x12\x13\n\x0b\x64\x65vice_type\x18\x06 \x01(\x05\"\xae\x06\n\x0fPlayAbilityConf\x12\x1f\n\x17\x62\x61\x63kground_play_disable\x18\x01 \x01(\x08\x12\x14\n\x0c\x66lip_disable\x18\x02 \x01(\x08\x12\x14\n\x0c\x63\x61st_disable\x18\x03 \x01(\x08\x12\x18\n\x10\x66\x65\x65\x64\x62\x61\x63k_disable\x18\x04 \x01(\x08\x12\x18\n\x10subtitle_disable\x18\x05 \x01(\x08\x12\x1d\n\x15playback_rate_disable\x18\x06 \x01(\x08\x12\x17\n\x0ftime_up_disable\x18\x07 \x01(\x08\x12\x1d\n\x15playback_mode_disable\x18\x08 \x01(\x08\x12\x1a\n\x12scale_mode_disable\x18\t \x01(\x08\x12\x14\n\x0clike_disable\x18\n \x01(\x08\x12\x17\n\x0f\x64islike_disable\x18\x0b \x01(\x08\x12\x14\n\x0c\x63oin_disable\x18\x0c \x01(\x08\x12\x14\n\x0c\x65lec_disable\x18\r \x01(\x08\x12\x15\n\rshare_disable\x18\x0e \x01(\x08\x12\x1b\n\x13screen_shot_disable\x18\x0f \x01(\x08\x12\x1b\n\x13lock_screen_disable\x18\x10 \x01(\x08\x12\x19\n\x11recommend_disable\x18\x11 \x01(\x08\x12\x1e\n\x16playback_speed_disable\x18\x12 \x01(\x08\x12\x1a\n\x12\x64\x65\x66inition_disable\x18\x13 \x01(\x08\x12\x1a\n\x12selections_disable\x18\x14 \x01(\x08\x12\x14\n\x0cnext_disable\x18\x15 \x01(\x08\x12\x17\n\x0f\x65\x64it_dm_disable\x18\x16 \x01(\x08\x12\x1c\n\x14small_window_disable\x18\x17 \x01(\x08\x12\x15\n\rshake_disable\x18\x18 \x01(\x08\x12\x18\n\x10outer_dm_disable\x18\x19 \x01(\x08\x12\x18\n\x10inner_dm_disable\x18\x1a \x01(\x08\x12\x1b\n\x13\x66reya_enter_disable\x18\x1b \x01(\x08\x12\x15\n\rdolby_disable\x18\x1c \x01(\x08\x12\x1a\n\x12\x66reya_full_disable\x18\x1d \x01(\x08\x12 \n\x18skip_oped_switch_disable\x18\x1e \x01(\x08\"\x81\x02\n\rPlayViewReply\x12\x36\n\nvideo_info\x18\x01 \x01(\x0b\x32\".bilibili.app.playurl.v1.VideoInfo\x12\x42\n\tplay_conf\x18\x02 \x01(\x0b\x32/.bilibili.pgc.gateway.player.v1.PlayAbilityConf\x12>\n\x08\x62usiness\x18\x03 \x01(\x0b\x32,.bilibili.pgc.gateway.player.v1.BusinessInfo\x12\x34\n\x05\x65vent\x18\x04 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v1.Event\"\xa5\x02\n\x0bPlayViewReq\x12\x0c\n\x04\x65pid\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\n\n\x02qn\x18\x03 \x01(\x03\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x06 \x01(\r\x12\x12\n\nforce_host\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x08\x12\r\n\x05spmid\x18\t \x01(\t\x12\x12\n\nfrom_spmid\x18\n \x01(\t\x12\x16\n\x0eteenagers_mode\x18\x0b \x01(\x05\x12<\n\x11prefer_codec_type\x18\x0c \x01(\x0e\x32!.bilibili.app.playurl.v1.CodeType\x12\x12\n\nis_preview\x18\r \x01(\x08\x12\x0f\n\x07room_id\x18\x0e \x01(\x03\"F\n\x0cProjectReply\x12\x36\n\x07project\x18\x01 \x01(\x0b\x32%.bilibili.app.playurl.v1.PlayURLReply\"\xed\x01\n\nProjectReq\x12\r\n\x05\x65p_id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\n\n\x02qn\x18\x03 \x01(\x03\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x06 \x01(\r\x12\x11\n\tforceHost\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x08\x12\r\n\x05spmid\x18\t \x01(\t\x12\x11\n\tfromSpmid\x18\n \x01(\t\x12\x10\n\x08protocol\x18\x0b \x01(\x05\x12\x13\n\x0b\x64\x65vice_type\x18\x0c \x01(\x05\x12\x1c\n\x14use_new_project_code\x18\r \x01(\x08\".\n\x12QualityDescription\x12\n\n\x02qn\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"A\n\x0fResponseDataUrl\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x13\n\x0bstream_type\x18\x02 \x01(\r\x12\x0c\n\x04ptag\x18\x03 \x01(\r\"\xa4\x01\n\x08RoomInfo\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\x12\x0b\n\x03uid\x18\x02 \x01(\x03\x12>\n\x06status\x18\x03 \x01(\x0b\x32..bilibili.pgc.gateway.player.v1.RoomStatusInfo\x12:\n\x04show\x18\x04 \x01(\x0b\x32,.bilibili.pgc.gateway.player.v1.RoomShowInfo\"S\n\x0cRoomShowInfo\x12\x10\n\x08short_id\x18\x01 \x01(\x03\x12\x18\n\x10popularity_count\x18\x08 \x01(\x03\x12\x17\n\x0flive_start_time\x18\n \x01(\x03\"\xce\x01\n\x0eRoomStatusInfo\x12\x13\n\x0blive_status\x18\x01 \x01(\x03\x12\x18\n\x10live_screen_type\x18\x02 \x01(\x03\x12\x11\n\tlive_mark\x18\x03 \x01(\x03\x12\x13\n\x0block_status\x18\x04 \x01(\x03\x12\x11\n\tlock_time\x18\x05 \x01(\x03\x12\x15\n\rhidden_status\x18\x06 \x01(\x03\x12\x13\n\x0bhidden_time\x18\x07 \x01(\x03\x12\x11\n\tlive_type\x18\x08 \x01(\x03\x12\x13\n\x0broom_shield\x18\t \x01(\x03\"\x15\n\x05Shake\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t2\xca\x02\n\x07PlayURL\x12\x66\n\x08PlayView\x12+.bilibili.pgc.gateway.player.v1.PlayViewReq\x1a-.bilibili.pgc.gateway.player.v1.PlayViewReply\x12\x63\n\x07Project\x12*.bilibili.pgc.gateway.player.v1.ProjectReq\x1a,.bilibili.pgc.gateway.player.v1.ProjectReply\x12r\n\x0cLivePlayView\x12/.bilibili.pgc.gateway.player.v1.LivePlayViewReq\x1a\x31.bilibili.pgc.gateway.player.v1.LivePlayViewReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.pgc.gateway.player.v1.playurl_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BUSINESSINFO']._serialized_start=119
  _globals['_BUSINESSINFO']._serialized_end=187
  _globals['_EVENT']._serialized_start=189
  _globals['_EVENT']._serialized_end=250
  _globals['_LIVEPLAYINFO']._serialized_start=253
  _globals['_LIVEPLAYINFO']._serialized_end=431
  _globals['_LIVEPLAYVIEWREPLY']._serialized_start=434
  _globals['_LIVEPLAYVIEWREPLY']._serialized_end=579
  _globals['_LIVEPLAYVIEWREQ']._serialized_start=581
  _globals['_LIVEPLAYVIEWREQ']._serialized_end=700
  _globals['_PLAYABILITYCONF']._serialized_start=703
  _globals['_PLAYABILITYCONF']._serialized_end=1517
  _globals['_PLAYVIEWREPLY']._serialized_start=1520
  _globals['_PLAYVIEWREPLY']._serialized_end=1777
  _globals['_PLAYVIEWREQ']._serialized_start=1780
  _globals['_PLAYVIEWREQ']._serialized_end=2073
  _globals['_PROJECTREPLY']._serialized_start=2075
  _globals['_PROJECTREPLY']._serialized_end=2145
  _globals['_PROJECTREQ']._serialized_start=2148
  _globals['_PROJECTREQ']._serialized_end=2385
  _globals['_QUALITYDESCRIPTION']._serialized_start=2387
  _globals['_QUALITYDESCRIPTION']._serialized_end=2433
  _globals['_RESPONSEDATAURL']._serialized_start=2435
  _globals['_RESPONSEDATAURL']._serialized_end=2500
  _globals['_ROOMINFO']._serialized_start=2503
  _globals['_ROOMINFO']._serialized_end=2667
  _globals['_ROOMSHOWINFO']._serialized_start=2669
  _globals['_ROOMSHOWINFO']._serialized_end=2752
  _globals['_ROOMSTATUSINFO']._serialized_start=2755
  _globals['_ROOMSTATUSINFO']._serialized_end=2961
  _globals['_SHAKE']._serialized_start=2963
  _globals['_SHAKE']._serialized_end=2984
  _globals['_PLAYURL']._serialized_start=2987
  _globals['_PLAYURL']._serialized_end=3317
# @@protoc_insertion_point(module_scope)
